Documentation
¶
Index ¶
- func MakeMergeSimpleLogJob(env cedar.Environment, logID string) amboy.Job
- func MakeSaveSimpleLogJob(env cedar.Environment, logID, content string, ts time.Time, inc int) amboy.Job
- func NewJasperManagerCleanup(id string, env cedar.Environment) amboy.Job
- func NewLocalAmboyStatsCollector(env cedar.Environment, id string) amboy.Job
- func NewRemoteAmboyStatsCollector(env cedar.Environment, id string) amboy.Job
- func NewStatsDBCollectionSizeJob(env cedar.Environment, id string) amboy.Job
- func NewSysInfoStatsCollector(id string) amboy.Job
- func StartCrons(ctx context.Context, env cedar.Environment, rpcTLS bool) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeMergeSimpleLogJob ¶
func MakeMergeSimpleLogJob(env cedar.Environment, logID string) amboy.Job
func MakeSaveSimpleLogJob ¶
func NewJasperManagerCleanup ¶
func NewJasperManagerCleanup(id string, env cedar.Environment) amboy.Job
NewJasperManagerCleanup reports basic system information and a report of the go runtime information, as provided by grip.
func NewLocalAmboyStatsCollector ¶
func NewLocalAmboyStatsCollector(env cedar.Environment, id string) amboy.Job
NewLocalAmboyStatsCollector reports the status of only the local queue registered in the evergreen service Environment.
func NewRemoteAmboyStatsCollector ¶
func NewRemoteAmboyStatsCollector(env cedar.Environment, id string) amboy.Job
NewRemoteAmboyStatsCollector reports the status of only the remote queue registered in the evergreen service Environment.
func NewStatsDBCollectionSizeJob ¶
func NewStatsDBCollectionSizeJob(env cedar.Environment, id string) amboy.Job
NewStatsDBCollectionSizeJob creates a new amboy job to collect the sizes of all collections in the Cedar DB and send them to Splunk.
func NewSysInfoStatsCollector ¶
NewSysInfoStatsCollector reports basic system information and a report of the go runtime information, as provided by grip.
func StartCrons ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.